<div align="center">
  <a href="https://v2.nonebot.dev/store"><img src="https://raw.githubusercontent.com/tkgs0/nbpt/resources/nbp_logo.png" width="180" height="180" alt="NoneBotPluginLogo"></a>
  <br>
  <p><img src="https://raw.githubusercontent.com/tkgs0/nbpt/resources/NoneBotPlugin.svg" width="240" alt="NoneBotPluginText"></p>
</div>

<div align="center">

# nonebot-plugin-wife

_✨ NoneBot 每日随机二次元老婆 ✨_


<a href="./LICENSE">
    <img src="https://img.shields.io/github/license/tkgs0/nonebot-plugin-wife.svg" alt="license">
</a>
<a href="https://pypi.python.org/pypi/nonebot-plugin-wife">
    <img src="https://img.shields.io/pypi/v/nonebot-plugin-wife.svg" alt="pypi">
</a>
<a href="https://www.python.org">
    <img src="https://img.shields.io/badge/python-3.9+-blue.svg" alt="python">
</a>
<a href="https://nonebot.dev">
    <img src="https://img.shields.io/badge/nonebot-2.3.1+-red.svg" alt="nonebot">
</a>
<a href="https://onebot.adapters.nonebot.dev">
    <img src="https://img.shields.io/badge/OneBot-11-black?logo=data:image/png;base64, " alt="onebot">
</a>

</div>


## 📖 介绍

于 [zbp](https://github.com/FloatTech/ZeroBot-Plugin) 移植的每日随机二次元老婆

## 💿 安装

**nb-cli安装, 包管理器安装  二选一**

<details>
<summary>使用 nb-cli 安装</summary>

在 nonebot2 项目的根目录下打开命令行, 输入以下指令即可安装

    nb plugin install nonebot-plugin-wife

</details>

<details>
<summary>使用包管理器安装</summary>

在 nonebot2 项目的插件目录下, 打开命令行,

**根据你使用的包管理器, 输入相应的安装命令**

<details>
<summary>pip</summary>

    pip install nonebot-plugin-wife

</details>
<details>
<summary>pdm</summary>

    pdm add nonebot-plugin-wife

</details>
<details>
<summary>poetry</summary>

    poetry add nonebot-plugin-wife

</details>
<details>
<summary>conda</summary>

    conda install nonebot-plugin-wife

</details>

打开 bot项目下的 `pyproject.toml` 文件,

在其 `plugins` 里加入 `nonebot_plugin_wife`

    plugins = ["nonebot_plugin_wife"]

</details>
</details>

## 🎉 使用

```
随机wife
随机老婆
抽wife
抽老婆
```

**以下为超级用户指令:**
```
添加wife [名字] [图片]
删除wife [名字]
查找wife [名字]

清空wife库
重置wife库
```

## ⚠️ 注意事项

**本插件目前仅支持 nonebot2 + onebot.v11 的使用方式, 一切非此二者结合的使用方式造成的问题请自行探索解决, 或者使用其他插件**
